=============================================
Echo Labware definition format (ELW and ELWX)
=============================================

.. currentmodule:: kithairon.labware

.. contents:: :local:

.. autopydantic_model:: EchoLabwareELW

.. autopydantic_model:: EchoLabwareELWX
